@@ -19,33 +19,32 @@
 #ifndef CONTACT_LIST_H
 #define CONTACT_LIST_H
 
-#include <KTp/Models/contacts-list-model.h>
-#include <KTp/Models/contacts-filter-model.h>
 #include <KTp/contact.h>
 
 #include <TelepathyQt/Types>
 
+namespace KTp {
+class ContactsModel;
+}
+
 /** Exposes general contact list stuff to QML*/
 class ContactList : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QObject* model READ filterModel CONSTANT)
+    Q_PROPERTY(KTp::ContactsModel* model READ filterModel CONSTANT)
 
   public:
     ContactList(QObject *parent=0);
-    KTp::ContactsFilterModel* filterModel() const;
+    KTp::ContactsModel* filterModel() const;
 
   public Q_SLOTS:
     void startChat(const Tp::AccountPtr &account, const KTp::ContactPtr &contact);
 
   private Q_SLOTS:
-    void onAccountManagerReady(Tp::PendingOperation *op);
     void onGenericOperationFinished(Tp::PendingOperation *op);
 
   private:
-    KTp::ContactsListModel* m_contactsModel;
-    KTp::ContactsFilterModel* m_filterModel;
-    Tp::AccountManagerPtr m_accountManager;
+    KTp::ContactsModel* m_filterModel;
 };
 
 #endif
